@@ -1,7 +1,12 @@
 import json
 import logging
 import threading
-from typing import List, Literal, Optional
+from typing import List, Optional
+try:
+    from typing import Literal
+except:
+    from typing_extensions import Literal
+
 from beartype import beartype
 
 from pglet import constants
@@ -10,7 +15,7 @@ from pglet.control import Control
 from pglet.control_event import ControlEvent
 from pglet.protocol import Command
 
-ALIGN = Literal[
+Align = Literal[
     None,
     "start",
     "end",
@@ -56,8 +61,9 @@ class Page(Control):
             self._session_id,
             [
                 Command(0, "get", ["page", "hash"], None, None, None),
-                Command(0, "get", ["page", "win_width"], None, None, None),
-                Command(0, "get", ["page", "win_height"], None, None, None),
+                Command(0, "get", ["page", "winwidth"], None, None, None),
+                Command(0, "get", ["page", "winheight"], None, None, None),
+                Command(0, "get", ["page", "userauthprovider"], None, None, None),
                 Command(0, "get", ["page", "userid"], None, None, None),
                 Command(0, "get", ["page", "userlogin"], None, None, None),
                 Command(0, "get", ["page", "username"], None, None, None),
@@ -66,13 +72,14 @@ class Page(Control):
             ],
         ).results
         self._set_attr("hash", values[0], False)
-        self._set_attr("win_width", values[1], False)
-        self._set_attr("win_height", values[2], False)
-        self._set_attr("userid", values[3], False)
-        self._set_attr("userlogin", values[4], False)
-        self._set_attr("username", values[5], False)
-        self._set_attr("useremail", values[6], False)
-        self._set_attr("userclientip", values[7], False)
+        self._set_attr("winwidth", values[1], False)
+        self._set_attr("winheight", values[2], False)
+        self._set_attr("userauthprovider", values[3], False)
+        self._set_attr("userid", values[4], False)
+        self._set_attr("userlogin", values[5], False)
+        self._set_attr("username", values[6], False)
+        self._set_attr("useremail", values[7], False)
+        self._set_attr("userclientip", values[8], False)
 
     def update(self, *controls):
         with self._lock:
@@ -147,8 +154,8 @@ class Page(Control):
     def on_event(self, e):
         logging.info(f"page.on_event: {e.target} {e.name} {e.data}")
 
-        if e.target == "page" and e.name == "change":
-            with self._lock:
+        with self._lock:
+            if e.target == "page" and e.name == "change":
                 for props in json.loads(e.data):
                     id = props["i"]
                     if id in self._index:
@@ -158,17 +165,17 @@ class Page(Control):
                                     name, props[name], dirty=False
                                 )
 
-        elif e.target in self._index:
-            self._last_event = ControlEvent(
-                e.target, e.name, e.data, self._index[e.target], self
-            )
-            handler = self._index[e.target].event_handlers.get(e.name)
-            if handler:
-                t = threading.Thread(
-                    target=handler, args=(self._last_event,), daemon=True
+            elif e.target in self._index:
+                self._last_event = ControlEvent(
+                    e.target, e.name, e.data, self._index[e.target], self
                 )
-                t.start()
-            self._event_available.set()
+                handler = self._index[e.target].event_handlers.get(e.name)
+                if handler:
+                    t = threading.Thread(
+                        target=handler, args=(self._last_event,), daemon=True
+                    )
+                    t.start()
+                self._event_available.set()
 
     def wait_event(self):
         self._event_available.clear()
@@ -268,7 +275,7 @@ class Page(Control):
 
     @horizontal_align.setter
     @beartype
-    def horizontal_align(self, value: ALIGN):
+    def horizontal_align(self, value: Align):
         self._set_attr("horizontalAlign", value)
 
     # vertical_align
@@ -278,7 +285,7 @@ class Page(Control):
 
     @vertical_align.setter
     @beartype
-    def vertical_align(self, value: ALIGN):
+    def vertical_align(self, value: Align):
         self._set_attr("verticalAlign", value)
 
     # gap
@@ -358,7 +365,7 @@ class Page(Control):
     # win_width
     @property
     def win_width(self):
-        w = self._get_attr("win_width")
+        w = self._get_attr("winwidth")
         if w != None and w != "":
             return int(w)
         return 0
@@ -366,7 +373,7 @@ class Page(Control):
     # win_height
     @property
     def win_height(self):
-        h = self._get_attr("win_height")
+        h = self._get_attr("winheight")
         if h != None and h != "":
             return int(h)
         return 0
@@ -377,8 +384,7 @@ class Page(Control):
         return self._get_attr("signin")
 
     @signin.setter
-    @beartype
-    def signin(self, value: Optional[bool]):
+    def signin(self, value):
         self._set_attr("signin", value)
 
     # signin_allow_dismiss
@@ -397,9 +403,15 @@ class Page(Control):
         return self._get_attr("signinGroups")
 
     @signin_groups.setter
-    def signin_groups(self, value):
+    @beartype
+    def signin_groups(self, value: Optional[bool]):
         self._set_attr("signinGroups", value)
 
+    # user_auth_provider
+    @property
+    def user_auth_provider(self):
+        return self._get_attr("userauthprovider")
+
     # user_id
     @property
     def user_id(self):
@@ -478,3 +490,21 @@ class Page(Control):
     @on_resize.setter
     def on_resize(self, handler):
         self._add_event_handler("resize", handler)
+
+    # on_connect
+    @property
+    def on_connect(self):
+        return self._get_event_handler("connect")
+
+    @on_connect.setter
+    def on_connect(self, handler):
+        self._add_event_handler("connect", handler)
+
+    # on_disconnect
+    @property
+    def on_disconnect(self):
+        return self._get_event_handler("disconnect")
+
+    @on_disconnect.setter
+    def on_disconnect(self, handler):
+        self._add_event_handler("disconnect", handler)
