@@ -1,7 +1,6 @@
 import logging
 import os
 import signal
-import subprocess
 import tarfile
 import tempfile
 import threading
@@ -9,32 +8,31 @@ import traceback
 import urllib.request
 import zipfile
 from pathlib import Path
-from threading import Thread
 from time import sleep
 
-from pglet.reconnecting_websocket import ReconnectingWebSocket
-from pglet.utils import *
 from pglet import constants
 from pglet.connection import Connection
 from pglet.event import Event
 from pglet.page import Page
+from pglet.reconnecting_websocket import ReconnectingWebSocket
+from pglet.utils import *
 
 
 def page(
     name=None,
     web=False,
+    update=False,
     server=None,
     token=None,
     permissions=None,
     no_window=False,
-    clean=True,
 ):
-    conn = _connect_internal(name, False, web, server, token, permissions, no_window)
+    conn = _connect_internal(
+        name, False, update, web, server, token, permissions, no_window
+    )
     print("Page URL:", conn.page_url)
     page = Page(conn, constants.ZERO_SESSION)
     conn.sessions[constants.ZERO_SESSION] = page
-    if clean:
-        page.clean()
     return page
 
 
@@ -52,7 +50,7 @@ def app(
         raise Exception("target argument is not specified")
 
     conn = _connect_internal(
-        name, True, web, server, token, permissions, no_window, target
+        name, True, False, web, server, token, permissions, no_window, target
     )
     print("App URL:", conn.page_url)
 
@@ -81,6 +79,7 @@ def app(
 def _connect_internal(
     name=None,
     is_app=False,
+    update=False,
     web=False,
     server=None,
     token=None,
@@ -135,7 +134,7 @@ def _connect_internal(
         if conn.page_name == None:
             conn.page_name = "*" if name == "" or name == None else name
         result = conn.register_host_client(
-            conn.host_client_id, conn.page_name, is_app, token, permissions
+            conn.host_client_id, conn.page_name, is_app, update, token, permissions
         )
         conn.host_client_id = result.hostClientID
         conn.page_name = result.pageName
@@ -171,9 +170,7 @@ def _start_pglet_server():
     pglet_exe = "pglet.exe" if is_windows() else "pglet"
 
     # check if pglet.exe exists in "bin" directory (user mode)
-    p = Path(__file__).parent.joinpath(
-        "bin", f"{get_platform()}-{get_arch()}", pglet_exe
-    )
+    p = Path(__file__).parent.joinpath("bin", pglet_exe)
     if p.exists():
         pglet_path = str(p)
         logging.info(f"Pglet Server found in: {pglet_path}")
@@ -212,7 +209,7 @@ def _download_pglet():
     pglet_bin = Path.home().joinpath(".pglet", "bin")
     pglet_bin.mkdir(parents=True, exist_ok=True)
 
-    pglet_version = _get_pglet_version()
+    pglet_version = constants.PGLET_SERVER_VERSION
 
     installed_ver = None
     pglet_path = pglet_bin.joinpath(pglet_exe)
@@ -244,17 +241,6 @@ def _download_pglet():
     return str(pglet_path)
 
 
-def _get_pglet_version():
-    appveyor_yml = Path(__file__).parent.parent.joinpath("appveyor.yml").absolute()
-
-    version_prefix = "PGLET_VERSION:"
-    with open(appveyor_yml) as yml:
-        for line in yml:
-            if version_prefix in line:
-                return line.split(":")[1].strip()
-    raise f"{version_prefix} not found in appveyor.yml"
-
-
 # Fix: https://bugs.python.org/issue35935
 # if _is_windows():
 #    signal.signal(signal.SIGINT, signal.SIG_DFL)
